from setuptools import setup

setup(
    name='pyllamaui',
    version='0.0.1',
    description='Reserved package name for PyllamaUI',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Bhuvanesh M',
    author_email='bhuvaneshm.developer@gmail.com',
    url='https://github.com/bhuvaneshm-dev/pyllamaui',
    packages=[],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License'
    ],
    python_requires='>=3.6',
)
